Index: lemon/topology.h
===================================================================
--- lemon/topology.h	(revision 1763)
+++ lemon/topology.h	(revision 1767)
@@ -697,15 +697,15 @@
   /// \ingroup topology
   ///
   /// \brief Checks the graph is node biconnected.
   ///
   /// This function checks that the undirected graph is node biconnected  
   /// graph. The graph is node biconnected if any two undirected edge is 
   /// on same circle.
   ///
   /// \param graph The graph.
   /// \return %True when the graph node biconnected.
   /// \todo Make it faster.
   template <typename UndirGraph>
-  bool nodeBiconnected(const UndirGraph& graph) {
+  bool biNodeConnected(const UndirGraph& graph) {
     return countNodeBiconnectedComponents(graph) == 1;
   }
@@ -715,5 +715,5 @@
   /// \brief Count the biconnected components.
   ///
   /// This function finds the node biconnected components in an undirected 
   /// graph. The biconnected components are the classes of an equivalence 
   /// relation on the undirected edges. Two undirected edge is in relationship
@@ -748,13 +748,13 @@
   /// \ingroup topology
   ///
   /// \brief Find the node biconnected components.
   ///
   /// This function finds the node biconnected components in an undirected 
   /// graph. The node biconnected components are the classes of an equivalence
   /// relation on the undirected edges. Two undirected edge are in relationship
   /// when they are on same circle.
   ///
   /// \image html node_biconnected_components.png
-  /// \image latex node_biconnected_components.eps "Node biconnected components" width=\textwidth
+  /// \image latex node_biconnected_components.eps "bi-node-connected components" width=\textwidth
   ///
   /// \param graph The graph.
@@ -766,5 +766,5 @@
   ///
   template <typename UndirGraph, typename UndirEdgeMap>
-  int nodeBiconnectedComponents(const UndirGraph& graph, 
+  int biNodeConnectedComponents(const UndirGraph& graph, 
 				UndirEdgeMap& compMap) {
     checkConcept<concept::UndirGraph, UndirGraph>();
@@ -794,8 +794,8 @@
   /// \ingroup topology
   ///
   /// \brief Find the node biconnected cut nodes.
   ///
   /// This function finds the node biconnected cut nodes in an undirected 
   /// graph. The node biconnected components are the classes of an equivalence
   /// relation on the undirected edges. Two undirected edges are in 
   /// relationship when they are on same circle. The biconnected components 
@@ -807,5 +807,5 @@
   /// \return The number of the cut nodes.
   template <typename UndirGraph, typename NodeMap>
-  int nodeBiconnectedCutNodes(const UndirGraph& graph, NodeMap& cutMap) {
+  int biNodeConnectedCutNodes(const UndirGraph& graph, NodeMap& cutMap) {
     checkConcept<concept::UndirGraph, UndirGraph>();
     typedef typename UndirGraph::Node Node;
@@ -1024,8 +1024,8 @@
   /// \ingroup topology
   ///
-  /// \brief Checks that the graph is edge biconnected.
-  ///
-  /// This function checks that the graph is edge biconnected. The undirected
-  /// graph is edge biconnected when any two nodes are connected with two
+  /// \brief Checks that the graph is bi-edge-connected.
+  ///
+  /// This function checks that the graph is bi-edge-connected. The undirected
+  /// graph is bi-edge-connected when any two nodes are connected with two
   /// edge-disjoint paths.
   ///
@@ -1034,5 +1034,5 @@
   /// \todo Make it faster.
   template <typename UndirGraph>
-  bool edgeBiconnected(const UndirGraph& graph) { 
+  bool biEdgeConnected(const UndirGraph& graph) { 
     return countEdgeBiconnectedComponents(graph) == 1;
   }
@@ -1040,8 +1040,8 @@
   /// \ingroup topology
   ///
   /// \brief Count the edge biconnected components.
   ///
   /// This function count the edge biconnected components in an undirected 
   /// graph. The edge biconnected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are  
   /// connected with at least two edge-disjoint paths.
@@ -1075,13 +1075,13 @@
   /// \ingroup topology
   ///
   /// \brief Find the edge biconnected components.
   ///
   /// This function finds the edge biconnected components in an undirected 
   /// graph. The edge biconnected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are  
   /// connected at least two edge-disjoint paths.
   ///
   /// \image html edge_biconnected_components.png
-  /// \image latex edge_biconnected_components.eps "Edge biconnected components" width=\textwidth
+  /// \image latex edge_biconnected_components.eps "bi-edge-connected components" width=\textwidth
   ///
   /// \param graph The graph.
@@ -1093,5 +1093,5 @@
   ///
   template <typename UndirGraph, typename NodeMap>
-  int edgeBiconnectedComponents(const UndirGraph& graph, NodeMap& compMap) { 
+  int biEdgeConnectedComponents(const UndirGraph& graph, NodeMap& compMap) { 
     checkConcept<concept::UndirGraph, UndirGraph>();
     typedef typename UndirGraph::NodeIt NodeIt;
@@ -1120,10 +1120,10 @@
   /// \ingroup topology
   ///
   /// \brief Find the edge biconnected cut edges.
   ///
   /// This function finds the edge biconnected components in an undirected 
   /// graph. The edge biconnected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are 
-  /// connected with at least two edge-disjoint paths. The edge biconnected 
+  /// connected with at least two edge-disjoint paths. The bi-edge-connected 
   /// components are separted by edges which are the cut edges of the 
   /// components.
@@ -1134,5 +1134,5 @@
   /// \return The number of cut edges.
   template <typename UndirGraph, typename UndirEdgeMap>
-  int edgeBiconnectedCutEdges(const UndirGraph& graph, UndirEdgeMap& cutMap) { 
+  int biEdgeConnectedCutEdges(const UndirGraph& graph, UndirEdgeMap& cutMap) { 
     checkConcept<concept::UndirGraph, UndirGraph>();
     typedef typename UndirGraph::NodeIt NodeIt;
@@ -697,15 +697,15 @@
   /// \ingroup topology
   ///
-  /// \brief Checks the graph is node biconnected.
-  ///
-  /// This function checks that the undirected graph is node biconnected  
-  /// graph. The graph is node biconnected if any two undirected edge is 
+  /// \brief Checks the graph is bi-node-connected.
+  ///
+  /// This function checks that the undirected graph is bi-node-connected  
+  /// graph. The graph is bi-node-connected if any two undirected edge is 
   /// on same circle.
   ///
@@ -697,15 +697,15 @@
   ///
   /// \param graph The graph.
-  /// \return %True when the graph node biconnected.
+  /// \return %True when the graph bi-node-connected.
   /// \todo Make it faster.
   template <typename UndirGraph>
@@ -715,5 +715,5 @@
   /// \brief Count the biconnected components.
   ///
-  /// This function finds the node biconnected components in an undirected 
+  /// This function finds the bi-node-connected components in an undirected 
   /// graph. The biconnected components are the classes of an equivalence 
   /// relation on the undirected edges. Two undirected edge is in relationship
@@ -748,13 +748,13 @@
   /// \ingroup topology
   ///
-  /// \brief Find the node biconnected components.
-  ///
-  /// This function finds the node biconnected components in an undirected 
-  /// graph. The node biconnected components are the classes of an equivalence
+  /// \brief Find the bi-node-connected components.
+  ///
+  /// This function finds the bi-node-connected components in an undirected 
+  /// graph. The bi-node-connected components are the classes of an equivalence
   /// relation on the undirected edges. Two undirected edge are in relationship
   /// when they are on same circle.
@@ -794,8 +794,8 @@
   /// \ingroup topology
   ///
-  /// \brief Find the node biconnected cut nodes.
-  ///
-  /// This function finds the node biconnected cut nodes in an undirected 
-  /// graph. The node biconnected components are the classes of an equivalence
+  /// \brief Find the bi-node-connected cut nodes.
+  ///
+  /// This function finds the bi-node-connected cut nodes in an undirected 
+  /// graph. The bi-node-connected components are the classes of an equivalence
   /// relation on the undirected edges. Two undirected edges are in 
   /// relationship when they are on same circle. The biconnected components 
@@ -1040,8 +1040,8 @@
   /// \ingroup topology
   ///
-  /// \brief Count the edge biconnected components.
-  ///
-  /// This function count the edge biconnected components in an undirected 
-  /// graph. The edge biconnected components are the classes of an equivalence
+  /// \brief Count the bi-edge-connected components.
+  ///
+  /// This function count the bi-edge-connected components in an undirected 
+  /// graph. The bi-edge-connected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are  
   /// connected with at least two edge-disjoint paths.
@@ -1075,13 +1075,13 @@
   /// \ingroup topology
   ///
-  /// \brief Find the edge biconnected components.
-  ///
-  /// This function finds the edge biconnected components in an undirected 
-  /// graph. The edge biconnected components are the classes of an equivalence
+  /// \brief Find the bi-edge-connected components.
+  ///
+  /// This function finds the bi-edge-connected components in an undirected 
+  /// graph. The bi-edge-connected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are  
   /// connected at least two edge-disjoint paths.
@@ -1120,10 +1120,10 @@
   /// \ingroup topology
   ///
-  /// \brief Find the edge biconnected cut edges.
-  ///
-  /// This function finds the edge biconnected components in an undirected 
-  /// graph. The edge biconnected components are the classes of an equivalence
+  /// \brief Find the bi-edge-connected cut edges.
+  ///
+  /// This function finds the bi-edge-connected components in an undirected 
+  /// graph. The bi-edge-connected components are the classes of an equivalence
   /// relation on the nodes. Two nodes are in relationship when they are 
